modulo

Function modulo 

pub fn modulo(left: Number, right: Number) -> Result<Number, String>
Modulo a Number by another Number.

left and right need to have the same UnitType, and the result will have that same UnitType.

Temperatures don’t work.